#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prim-uniq
version:              0.2
visibility:           public
id:                   prim-uniq-0.2-4HBJzdJPLw6CwEdwEPixvW
key:                  prim-uniq-0.2-4HBJzdJPLw6CwEdwEPixvW
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/prim-uniq
synopsis:             Opaque unique identifiers in primitive state monads
description:
    Opaque unique identifiers in primitive state monads
    and a GADT-like type using them as witnesses of type
    equality.

category:             Data, Dependent Types
abi:                  13afbb106c495cb311f4226fe441240f
exposed:              True
exposed-modules:
    Data.Unique.Prim Data.Unique.Tag Unsafe.Unique.Prim
    Unsafe.Unique.Tag

import-dirs:          /usr/lib/ghc-9.6.6/site-local/prim-uniq-0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/prim-uniq-0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/prim-uniq-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prim-uniq
hs-libraries:         HSprim-uniq-0.2-4HBJzdJPLw6CwEdwEPixvW
depends:
    base-4.18.2.1 dependent-sum-0.7.2.0-IR9UOCzrLxCB4QX88EWTTO
    primitive-0.9.1.0-2IRhja9DqVYHGJwyknHO82

haddock-interfaces:   /usr/share/doc/haskell-prim-uniq/html/prim-uniq.haddock
haddock-html:         /usr/share/doc/haskell-prim-uniq/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

